@@ -1,34 +1,50 @@
-## Copyright 2013-2015 Sebastian Gibb
-## <mail@sebastiangibb.de>
+## .scalingFactor
+## calculate scaling factor for TIC/median ranged calibration
 ##
-## This file is part of MALDIquant for R and related languages.
+## params:
+##  object: AbstractMassObject
+##  method: character
+##  range: double
 ##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
+## returns:
+##  double
 ##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
+.scalingFactor <- function(object, method=c("TIC", "median"), range) {
+
+  method <- match.arg(method)
+
+  if (!missing(range)) {
+    object <- trim(object, range=range)
+  }
+
+  switch(method,
+    "TIC" = {
+      totalIonCurrent(object)
+    },
+    "median" = {
+      median(object@intensity)
+    }
+  )
+}
 
 ## .calibrateIntensitySimple
 ## calibrate intensity values by offset and scaling factor
 ##
 ## params:
 ##  y: double, intensity values
-##  offset: double/function
-##  scaling: double/function
+##  offset: double
+##  scaling: double
 ##
 ## returns:
 ##  double, calibrated intensity values
 ##
 .calibrateIntensitySimple <- function(y, offset=0L, scaling=1L) {
-  (y - offset) / scaling
+  if (scaling == 0L) {
+    warning("Scaling factor is zero. No calibration applied.")
+    y
+  } else {
+    (y - offset) / scaling
+  }
 }
 
 ## .calibrateProbabilisticQuotientNormalization
@@ -51,15 +67,21 @@
 ##
 ## params:
 ##  l: list of MassSpectrum objects
+##  range: double
 ##
 ## returns:
 ##  list of calibrated MassSpectrum objects
 ##
-.calibrateProbabilisticQuotientNormalization <- function(l) {
+.calibrateProbabilisticQuotientNormalization <- function(l, range) {
   ## 1. integral normalization (==TIC)
-  l <- calibrateIntensity(l, method="TIC")
+  l <- calibrateIntensity(l, method="TIC", range=range)
   ## 2. median reference spectrum
-  reference <- .averageMassSpectra(l, fun=.colMedians, mergeMetaData=FALSE)
+  if (missing(range)) {
+    reference <- .averageMassSpectra(l, fun=.colMedians, mergeMetaData=FALSE)
+  } else {
+    reference <- .averageMassSpectra(trim(l, range=range), fun=.colMedians,
+                                     mergeMetaData=FALSE)
+  }
 
   lapply(l, function(x) {
     ## 3. quotient calculation
