@@ -113,7 +113,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   ## sample peaks
   binnedMass <- .binPeaks(mass=mass, intensities=intensities, samples=samples,
                           tolerance=tolerance,
-                          grouper=.grouperRelaxedHighestAtReference)
+                          grouper=.grouperRelaxedHighestAtReference, nomatch=0L)
 
   ## group mass/intensities by sample ids
   lIdx <- split(seq_along(binnedMass), samples)
@@ -141,8 +141,8 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
                       samples[i[1L]] - 1L, " to a reference peak.")
       NA
     } else if (length(arguments$x) < minPeaks) {
-      nomatchReporter("Could not match enough peaks in spectrum",
-                      samples[i[1L]] - 1L, "to the reference peaks.\n",
+      nomatchReporter("Could not match enough peaks in spectrum ",
+                      samples[i[1L]] - 1L, " to the reference peaks.\n",
                       minPeaks, " matches required, just ",
                       length(arguments$x), " found.")
       NA
